@@ -320,7 +320,8 @@ typedef RRP *prRP;
 /*                                                                          */
 /****************************************************************************/
 
-#define  MGRVALIDATE   'MG'
+#define  PACK(a,b) ((a<<8)||b)
+#define  MGRVALIDATE PACK('M','G')
 typedef struct rmgr { /**/
       USHORT     MGR_achValid;
       USHORT     MGR_usID;             /* Manager ID (not used yet)         */
@@ -338,7 +339,7 @@ typedef struct rmgr { /**/
 /*                                                                          */
 /****************************************************************************/
 
-#define  DSPVALIDATE   'SP'
+#define  DSPVALIDATE PACK('S','P')
 
 typedef struct rdsp { /**/
       USHORT     DSP_achValid;         /* validation of structure = 'SP'    */
@@ -422,7 +423,7 @@ typedef struct rdsp { /**/
 /* IPC Table Entry.                                                         */
 /****************************************************************************/
 
-#define  IPCTEVALIDATE 'TE'
+#define  IPCTEVALIDATE PACK('T','E')
 typedef struct ripcte { /**/
       USHORT     IPCTE_achValid;       /* validation of structure = 'TE'    */
       USHORT     IPCTE_usMask;         /* IPC Mask 0000-8000                */
@@ -456,7 +457,7 @@ typedef struct ripcte { /**/
 /*                                                                          */
 /****************************************************************************/
 
-#define  FMVALIDATE    'FM'
+#define  FMVALIDATE   PACK('F','M')
 typedef struct rfm { /**/
       USHORT     FM_achValid;          /* validation of structure = 'FM'    */
       USHORT     FM_usUseCount;        /* count of tasks using this FM      */
@@ -533,7 +534,7 @@ typedef struct ritcbcl { /**/
 /*                                                                          */
 /****************************************************************************/
 
-#define  MODVALIDATE   'MD'
+#define  MODVALIDATE  PACK('M','D')
 typedef struct rmod { /**/
       USHORT     MOD_achValid;         /* Validation of structure = 'MD'    */
       USFLG      MOD_usflgState;
@@ -574,7 +575,7 @@ typedef struct rmod { /**/
 /*                                                                          */
 /****************************************************************************/
 
-#define  TSKVALIDATE   'TK'
+#define  TSKVALIDATE   PACK('T','K')
 typedef struct rtsk { /**/
       USHORT     TSK_achValid;         /* Validation of structure = 'TK'    */
       USFLG      TSK_usflgType;        /* Flag: timer or Sample Rate        */
@@ -649,7 +650,7 @@ typedef struct rtsktmp { /**/
 /*                                                                          */
 /****************************************************************************/
 
-#define  SEGVALIDATE   'SG'
+#define  SEGVALIDATE   PACK('S','G')
 typedef struct rseg { /**/
       USHORT     SEG_achValid;         /* validation of structure = 'SG'    */
       USFLG      SEG_usflg;            /* Segment flags                     */
@@ -766,7 +767,7 @@ typedef struct rimg { /**/
 /*                                                                          */
 /****************************************************************************/
 
-#define  LDMAVALIDATE  'LD'
+#define  LDMAVALIDATE  PACK('L','D')
 typedef struct rldma { /**/
       USHORT     LDMA_achValid;        /* Validation of structure = 'LD'    */
       USFLG      LDMA_usflg;           /* DMA flags                         */
@@ -797,7 +798,7 @@ typedef struct rldma { /**/
 /*                                                                          */
 /****************************************************************************/
 
-#define  GPCVALIDATE   'GP'
+#define  GPCVALIDATE   PACK('G','P')
 typedef struct rgpc { /**/
       USHORT     GPC_achValid;         /* Validation of structure = 'GP'    */
       USFLG      GPC_usflgKind;        /* OWNER=0 USER=1 Vowner=2 Vuser=3   */
@@ -932,7 +933,7 @@ typedef struct gpcsynctemplate *PRGPCTMP;
 /*                                                                          */
 /****************************************************************************/
 
-#define  ITCBVALIDATE  'IT'
+#define  ITCBVALIDATE  PACK('I','T')
 typedef struct ritcb { /**/
       USHORT     ITCB_achValid;        /* Validation of structure = 'IT'    */
       USFLG      ITCB_usflgKind;       /* Primary or Secondary              */
@@ -1086,7 +1087,7 @@ typedef struct rfix { /**/
 /*                                                                          */
 /****************************************************************************/
 
-#define  HWVALIDATE    'HW'
+#define  HWVALIDATE    PACK('H','W')
 typedef struct rhw { /**/
       PRHW       HW_prhwNext;          /* (CLL) Next in HW list             */
       PRTSK      HW_prtsk;             /* Owning BIOS Task                  */
