@@ -484,6 +484,7 @@ void FreeMwaveAPIAnswerBuffer( BYTE * pbAnswerBuffer )
 DWORD StartMwaveAPIServer( void )
 {
     ULONG ulRC;
+    char mwave_device[32];
 
     //
     // Allocate Manager Heaps
@@ -500,7 +501,9 @@ DWORD StartMwaveAPIServer( void )
     pg->usDaemonFunc = 0xffff;          // illegal function
 
     // Open Driver
-    hDrv=open("/dev/modems/mwave",O_RDWR);
+    GetPrivateProfileString("STARTUP", "DEVICE", "/dev/modems/mwave",
+		mwave_device, sizeof(mwave_device), ini_file);
+    hDrv=open(mwave_device,O_RDWR);
     if (!hDrv) {
       MW_SYSLOG_1(TRACE_MANAGER_SPECIFIC,"dspsrv::StartMwaveAPIServer, unable to open mwave device driver\n");
       return -1;
@@ -860,7 +863,7 @@ RC ManagerInit(VOID)
                ulRC = RecordBios(prmgr, pszBIOSFileName);
 
                prdsp = prdsp->DSP_prdspNext; // Move to next DSP
-               i = i++;                // Move to next ISPxxx Vitrual Name
+               i++;                // Move to next ISPxxx Vitrual Name
 
             }  while (prdsp != prdspHead);
 
