@@ -463,7 +463,7 @@ union          /* make complete structure a single entity for memtransfer */
      unsigned int reserved    : 10;     /* not used */
   } Ctl;
   ULONG Data;              /* ULONG reference for I/O */
-} TelephonyCodec16 = {0L};
+} TelephonyCodec16 = { {0L} };
 
 USHORT TelephonyCodecUpdated = 1;/* flag to signal update required */
 
@@ -504,7 +504,7 @@ union          /* make complete structure a single entity for memtransfer */
      unsigned int reserved    : 9 ;     /* not used */
   } Ctl;
   ULONG Data;              /* ULONG reference for I/O */
-} CDCodec16 = {0L};
+} CDCodec16 = { {0L} };
 
 PMEIO_DSP pMEIODSP;
 USHORT CDCodecUpdated = 1;/* flag to signal update required */
