@@ -286,11 +286,11 @@ ULONG failRequestDialPermission (UnsuccessfulRecord *pRec, time_t CurrentTime,
   ULONG ulError;
 
   MW_SYSLOG_2(TRACE_MWMBL,"unsucces::failRequestDialPermission pRec %p\n",pRec);
-  MW_SYSLOG_2(TRACE_MWMBL,"  bInitialized %lx\n",pRec->bInitialized);
+  MW_SYSLOG_2(TRACE_MWMBL,"  bInitialized %x\n",pRec->bInitialized);
   MW_SYSLOG_2(TRACE_MWMBL,"  szPhoneNumber %s\n",pRec->szPhoneNumber);
-  MW_SYSLOG_2(TRACE_MWMBL,"  ulRecordStatus %x\n",pRec->ulRecordStatus);
-  MW_SYSLOG_2(TRACE_MWMBL,"  ulUnsuccessfulCount %x\n",pRec->ulUnsuccessfulCount);
-  MW_SYSLOG_2(TRACE_MWMBL,"  ulNonBusyUnscessfulCount %x\n",pRec->ulNonBusyUnsuccessfulCount);
+  MW_SYSLOG_2(TRACE_MWMBL,"  ulRecordStatus %lx\n",pRec->ulRecordStatus);
+  MW_SYSLOG_2(TRACE_MWMBL,"  ulUnsuccessfulCount %lx\n",pRec->ulUnsuccessfulCount);
+  MW_SYSLOG_2(TRACE_MWMBL,"  ulNonBusyUnscessfulCount %lx\n",pRec->ulNonBusyUnsuccessfulCount);
   MW_SYSLOG_7(TRACE_MWMBL,"  %lx,%lx,%lx,%lx,%lx,%lx\n",pRec->TimeStampArray[0],
 	      pRec->TimeStampArray[1],     
 	      pRec->TimeStampArray[2],
