@@ -915,7 +915,7 @@ RC mwmCntndMEIOConnect(HCONNECTION FAR *pConnection, ULONG OwnerPort,
   int     numTries=1, retry=0;
   ULONG   ulRC;
 
-  { MW_SYSLOG_7(TRACE_MWMLW32,"mwmcntnd::mwmCntndMEIOConnect entry hMEIO %x pConnection %p OwnerPort %lx UserPort %lx SharingOptions %lx ulState %lx\n",
+  { MW_SYSLOG_7(TRACE_MWMLW32,"mwmcntnd::mwmCntndMEIOConnect entry hMEIO %lx pConnection %p OwnerPort %lx UserPort %lx SharingOptions %lx ulState %lx\n",
 	hMEIO,pConnection,OwnerPort,UserPort,SharingOptions,ulState);  }
 
 
