@@ -457,7 +457,7 @@ ULONG mwmV80LCyclesAdjustToLineSpeed(PMWM_DSPINFO pmwmDspInfo, /*$H*/
 {
 
   ULONG   ulAddress = 0;
-  ULONG   ulRC;
+  ULONG   ulRC=0;
 
 	 { MW_SYSLOG_1(TRACE_MWMLW32,"mwmv80l::mwmV80LCyclesAdjustToLineSpeed entry\n");  }
 
@@ -1065,7 +1065,7 @@ ULONG mwmV80LGetSUBCLASS(PMWM_DSPINFO pmwmDspInfo, USHORT *pusSUBCLASS)  /*$3*/
 
 /*  DPF("  SUBCLASS = %d\n", *pusSUBCLASS);*/
 
-	 { MW_SYSLOG_2(TRACE_MWMLW32,"mwmv80l::mwmV80LGetSUBCLASS exit usSUBCLASS %lx\n",*pusSUBCLASS);  }
+	 { MW_SYSLOG_2(TRACE_MWMLW32,"mwmv80l::mwmV80LGetSUBCLASS exit usSUBCLASS %x\n",*pusSUBCLASS);  }
 
 
   return 0;
