@@ -305,8 +305,7 @@ USHORT  mwmClss2FMINSPCommand(STATEINFO *psi)
   usParm = mwmParseGetArgFromATString(psi->achCommandBuffer,
                                       &psi->usNextATIndex);
 
-  if ((usParm >= 0) && 
-      (usParm <= 3)) {
+  if (usParm <= 3) {
     psi->Class2Capabilities.usFMINSP = usParm;
 
     /**************************************************************
@@ -1228,6 +1227,7 @@ USHORT  mwmClss2FKCommand(STATEINFO *psi)
 
 
 
+extern void swab() __THROW;
 
 USHORT  mwmClss2FLIDCommand(STATEINFO *psi)
 {
