@@ -129,7 +129,7 @@ int FAR PASCAL mwmIPC1InterruptHandler(void)
   if (!usControlStat) {
     /* HACK. Sometimes the mwave chip interrupts before the control status register has been set. If this is the */
     /*       case just assume that a usControlStat of 4 was what was meant */
-    MW_SYSLOG_ERROR(LOG_ERR,"mwmipc1::mwmIPC1InterruptHandler, ERROR usControlStat %x (setting to 4)\n",usControlStat);
+    MW_SYSLOG_ERROR(LOG_ERR,"mwmipc1::mwmIPC1InterruptHandler, WARNING usControlStat was %x (setting to 4)\n",usControlStat);
     usControlStat=4; 
   }
   switch (usControlStat)
