@@ -704,7 +704,7 @@ USHORT mwmPercentTTCommand(STATEINFO *psi)
 
         if (strlen(pszParm))
         {
-          sscanf(pszParm,"%x",&(psi->ausPPcmdBuffer[psi->usNextPPIndex++]));
+          sscanf(pszParm,"%x",(unsigned int *)&(psi->ausPPcmdBuffer[psi->usNextPPIndex++]));
         }
         /*********************************************************************/
         /* Increment to prepare for the next parameter.                      */
