@@ -1503,7 +1503,7 @@ USHORT  mwmPlusA8ECommand(STATEINFO *psi)
 
       if (strlen(achParm))
       {
-        sscanf(achParm,"%x",&usParm);
+        sscanf(achParm,"%hx",&usParm);
 
         DPF("Parameter %u = %x\n",usParmNumber,usParm);
         /*********************************************************************/
