@@ -409,16 +409,18 @@ BOOL MWM_ENTRY mwmPoundUDFillBuffer()
       /*#define pBuf                  buffer+j, buffer_size-j*/
       #define pBuf                   (char*)ud_buffer+j
       #define DiagLineStart()        j+=sprintf(pBuf, "%s", szStartToken)
-      #define DiagWORD(base,keynum)  if ( pCS->base.IsValid & BIT((0x ## keynum & 0xF)) ) \
+      #define DiagWORD(base,keynum)  if ( pCS->base.IsValid & BIT((0x ## keynum & 0xF)) ) { \
                                        if (psi->bPoundUDDecimal) \
                                          j+=sprintf(pBuf, " %s=%u", #keynum, pCS->base.Key ## keynum);  \
-                                       else \
-                                         j+=sprintf(pBuf, " %s=%X", #keynum, pCS->base.Key ## keynum)
-      #define DiagDWORD(base,keynum) if ( pCS->base.IsValid & BIT((0x ## keynum & 0xF)) )  \
+				       else \
+                                         j+=sprintf(pBuf, " %s=%X", #keynum, pCS->base.Key ## keynum); \
+				     }
+      #define DiagDWORD(base,keynum) if ( pCS->base.IsValid & BIT((0x ## keynum & 0xF)) ) { \
                                        if (psi->bPoundUDDecimal) \
                                          j+=sprintf(pBuf, " %s=%lu", #keynum, pCS->base.Key ## keynum); \
-                                       else \
-                                         j+=sprintf(pBuf, " %s=%lX", #keynum, pCS->base.Key ## keynum) 
+				       else  \
+                                         j+=sprintf(pBuf, " %s=%lX", #keynum, pCS->base.Key ## keynum); \
+				     } 
       #define DiagStr(base,keynum)   if ( pCS->base.IsValid & BIT((0x ## keynum & 0xF)) ) \
                                        j+=sprintf(pBuf, " %s=%s", #keynum, pCS->base.Key ## keynum)
       #define DiagLineEnd()          j+=sprintf(pBuf, ">"); j++
